import { sendErrorResponse } from "../core";
import { Monitor } from "../repository";


export async function getMonitor(req, res) {
    try {
        const monitor = await Monitor.findMonitorById(req.params.id);

        if (!monitor) {
            res.status(404).send({ message: "Monitor not found" });
            return;
        }
        res.status(200).send(monitor);
    } catch (error) {
        console.info("GET monitor ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function getMonitorUsers(req, res) {
    try {
        const users = await Monitor.findMonitorUsers(req.params.id);

        res.status(200).send(users);
    } catch (error) {
        console.info("GET monitor users ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function getMonitorWorkouts(req, res) {
    try {
        const workouts = await Monitor.findMonitorWorkouts(req.params.id);

        res.status(200).send(workouts);
    } catch (error) {
        console.info("GET monitor workouts ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function updateMonitor(req, res) {
    try {
        const { id } = req.params;
        const { name, surname, email, password, birthday, gender } = req.body;

        await Monitor.updateMonitor({
            id,
            name, 
            surname, 
            email, 
            password, 
            birthday, 
            gender
        });

        res.status(201).send();
    } catch (error) {
        console.info("UPDATE MONITOR ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}
