import moment from "moment";
import { sendErrorResponse } from "../core";
import { Users } from "../repository";


export async function getUser(req, res) {
    try {
        const user = await Users.findUserById(req.params.id);
        if(!user) {
            res.status(404).send({ message: "User not found" });
            return;
        }
        res.status(200).send(user);
    } catch (error) {
        console.info("GET user ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function updateUser(req, res) {
    try {
        const { id } = req.params;
        const { name, surname, email, password, birthday, gender } = req.body;


        await Users.updateUser({
            id,
            name, 
            surname, 
            email, 
            password, 
            birthday, 
            gender
        });

        res.status(201).send();
    } catch (error) {
        console.info("UPDATE USER ERROR", moment(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function updateUserWorkout(req, res) {
    try {
        const { id } = req.params;
        const { workoutId } = req.body;

        await Users.updateUserWorkout({
            id,
            workoutId
        });

        res.status(201).send();
    } catch (error) {
        console.info("UPDATE USER WORKOUT ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function startUserWorkout(req, res) {
    try {
        const {userId, workoutId } = req.body;

        await Users.startWorkout({userId, workoutId });

        res.status(201).send();
    } catch (error) {
        console.info("UPDATE START_USER_WORKOUT ERROR", moment(), " with error ", error);
        sendErrorResponse(res, error);
    }
}
export async function stopUserWorkout(req, res) {
    try {
        const {userId, workoutId } = req.body;


        await Users.stopWorkout({userId, workoutId });

        res.status(201).send();
    } catch (error) {
        console.info("UPDATE STOP_USER_WORKOUT ERROR", moment(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function getUserStatistics(req, res) {
    try {
        //Statistic 1
        const userAccess = await Users.getUserAccess(req.params.id);
        const accesosGimnasioDatos = Array(12).fill(0);
        for(const userAcces of userAccess) {
            const date = new Date(userAcces.date);
            accesosGimnasioDatos[date.getMonth()] ++;
        }
        
        //Statistic 2
        const now = new Date();
        const onejan = new Date(now.getFullYear(), 0, 1);
        const week = Math.ceil((((now.getTime() - onejan.getTime()) / 86400000) + onejan.getDay() + 1) / 7);

        const [userWorksThisWeek, metadata] = await Users.getUserTimeWorkThisWeek(req.params.id, week-1);
        let startWork = null;
        const tiempoEntreneSemanaDatos = Array(7).fill(0);
        for(const userWork of userWorksThisWeek) {
            if(userWork.type === "START") {
                startWork = userWork.date;
                continue;
            }
            let day = (new Date(userWork.date)).getDay() -1 ;
            day = day === -1 ? 6 : day
            const diff = Math.abs(new Date(userWork.date) - new Date(startWork));
            const minutes = Math.ceil((diff/1000)/60);
            tiempoEntreneSemanaDatos[day] += minutes;
            console.log("day ", day, " date ", userWork.date, " diff ", diff, " minutes ", minutes);
        }

        //Statistic 3
        const [workoutComplete, metadataUserWorks] = await Users.getUserWorksThisMonth(req.params.id, now.getMonth()+1);
        const totalDays = (new Date(now.getFullYear(), now.getMonth()+1, 0)).getDate();
        const currentDays = now.getDate();
        const completed = workoutComplete[0].total || 0;
        const rutinasCompletadasDatos = {
            completed,
            incompleted: currentDays - completed,
            pending: totalDays - currentDays
        };
        res.status(200).send({accesosGimnasioDatos, tiempoEntreneSemanaDatos, rutinasCompletadasDatos});
    } catch (error) {
        console.info("GET UserStatistics ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}