import { sendErrorResponse } from "../core";
import { Users, Workout } from "../repository";
import { DateUtils } from "../utils";


export async function getWorkout(req, res) {
    try {
    const workout = await Workout.findWorkoutById({ id: req.params.id })
        if (workout == null) {
        res.status(404).send({ message: "Workout not found" });
        return;
        }
        res.status(200).send(workout);
    } catch (error) {
        console.info("GET WORKOUT ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function getUserWorkout(req, res) {
    try {
        const user = await Users.findUserById(req.params.id);
        const workout = await Workout.findWorkoutById({ id: user.idWorkout})
        if (workout == null) {
            res.status(404).send({ message: "Workout not found" });
            return;
        }
        const exercises = await Workout.findExercicesWorkoutById({id: workout.id});
        res.status(200).send({ id:workout.id, name: workout.name, exercises });
    } catch (error) {
        console.info("GET WORKOUT ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function createWorkout(req, res) {
    try {
        const { workoutName, monitorId } = req.body;

        const date = DateUtils.getToday();
        const workout = await Workout.insertWorkout({
            name: workoutName,
            date,
            idMonitor: monitorId
        });

        res.status(200).send({workoutId: workout.id});
      } catch (error) {
        console.info("CREATE WORKOUT ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
  }
  
export async function updateWorkout(req, res) {
    try {
        const { id, name } = req.body;
        //TODO: Sacar idMonitor del middleware
        const idMonitor = 1;

        const workout = await Workout.findWorkoutById({id});
        if (workout === null) {
            res.status(404).send({message: "Workout not found"});
            return;
        }

        const date = DateUtils.getToday();
        await Workout.updateWorkout({
        id,
        name,
        date,
        idMonitor
        });

        res.status(201).send();
    } catch (error) {
        console.info("UPDATE WORKOUT ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function deleteWorkout(req, res) {
    try {
        const { workoutId } = req.body;

        await Workout.deleteWorkout({ id:workoutId });

        res.status(201).send();
    } catch (error) {
        console.info("DELETE WORKOUT ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
}

export async function addExerciseToWorkout(req, res) {
    try {
        const { workoutId, exerciseId } = req.body;
        
        await Workout.addExerciseToWorkout({
            workoutId,
            exerciseId
        });

        res.status(201).send();
      } catch (error) {
        console.info("addExerciseToWorkout ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
  }

  export async function deleteExerciseToWorkout(req, res) {
    try {
        const { workoutId, exerciseId } = req.params;

        await Workout.deleteExerciseToWorkout({
            workoutId,
            exerciseId
        });

        res.status(201).send();
      } catch (error) {
        console.info("addExerciseToWorkout ERROR", new Date(), " with error ", error);
        sendErrorResponse(res, error);
    }
  }
