import crypto from "crypto"; //"crypto-js": "^3.1.9-1",
import jwt from "jwt-simple";
import moment from "moment";
import { config } from "../config";
/**
 * Crea el token en base a la unidad de tiempo (horas, minutos, segundos) y al número o cantidad (1,2,3,10...)
 *
 * @param {*} user
 * @returns
 */
function createToken(user) {
  const { EXPIRATION_NUMBER, EXPIRATION_UNIT, TOKEN_SECRET } = config;

  const payload = {
    sub: user.id,
    iat: moment().unix(),
    exp: moment()
      .add(EXPIRATION_NUMBER, EXPIRATION_UNIT)
      .unix()
  };

  return jwt.encode(payload, TOKEN_SECRET);
}

function decodeToken(token) {
  const { TOKEN_SECRET } = config;
  try {
    const { secretKeyJWT } = config;
    return jwt.decode(token, TOKEN_SECRET);
  } catch (err) {
    return null;
  }
}

const sendErrorResponse = (res, error) => {
  res
    .status((error.response && error.response.status) || 500)
    .send(
      (error.response && error.response.data) || { message: error.message }
    );
};

function AESencrypt(text) {
  const cipher = crypto.createCipheriv(
    "aes-256-cbc",
    config.AES_TOKEN_SECRET,
    config.ivAES
  );
  let encrypted = cipher.update(text.toString());
  // eslint-disable-next-line no-undef
  encrypted = Buffer.concat([encrypted, cipher.final()]);
  return encrypted.toString("hex");
}

function AESdecrypt(text) {
  // eslint-disable-next-line no-undef
  const encryptedText = Buffer.from(text, "hex");
  const decipher = crypto.createDecipheriv(
    "aes-256-cbc",
    config.AES_TOKEN_SECRET,
    config.ivAES
  );
  let decrypted = decipher.update(encryptedText);
  // eslint-disable-next-line no-undef
  decrypted = Buffer.concat([decrypted, decipher.final()]);
  return decrypted.toString();
}

export { createToken, decodeToken, sendErrorResponse, AESencrypt, AESdecrypt };
