#!/usr/bin/env node

/**
 * Module dependencies.
 */

import "@babel/polyfill"; // Sin esto no funcionará la asincronía con Promesas, después de compilar con babel
import Debug from "debug";
import * as fs from 'fs';
import http from "http";
import https from 'https';
import process from "process";
import app from "./app";
import models from "./models";

const debug = Debug("express-sequelize");

const key = fs.readFileSync(__dirname + '/../selfsigned.key');
const cert = fs.readFileSync(__dirname + '/../selfsigned.crt');
const options = {
  key: key,
  cert: cert
};

/**
 * Get port from environment and store in Express.
 */

const port = normalizePort(process.env.PORT || "3100");
app.set("port", port);
/**
 * Create HTTP server.
 */
const server = http.createServer(app);

const serverHttps = https.createServer(options, app);

models.sequelize.sync().then(() => {
  /**
   * Listen on provided port, on all network interfaces.
   */
   serverHttps.listen(3101, () => {
    console.log("server starting on port : 3101");
  });
  server.listen(port, () => {
    debug(`Express server listening on port ${server.address().port}`);
  });
  server.on("error", onError);
  server.on("listening", onListening);
});

/**
 * Normalize a port into a number, string, or false.
 */

function normalizePort(val) {
  const port = parseInt(val, 10);

  if (isNaN(port)) {
    // named pipe
    return val;
  }

  if (port >= 0) {
    // port number
    return port;
  }

  return false;
}

/**
 * Event listener for HTTP server "error" event.
 */

function onError(error) {
  if (error.syscall !== "listen") {
    throw error;
  }

  const bind = typeof port === "string" ? `Pipe ${port}` : `Port ${port}`;

  // handle specific listen errors with friendly messages
  switch (error.code) {
    case "EACCES":
      console.error(`${bind} requires elevated privileges`); // eslint-disable-line
      process.exit(1);

    case "EADDRINUSE":
      console.error(`${bind} is already in use`); // eslint-disable-line
      process.exit(1);
    default:
      throw error;
  }
}

/**
 * Event listener for HTTP server "listening" event.
 */

function onListening() {
  const addr = server.address();
  const bind = typeof addr === "string" ? `pipe ${addr}` : `port ${addr.port}`;
  debug(`Listening on ${bind}`);
}
