import jwt from "jwt-simple";
import { config } from "../config";

/**
 * Middleware que evita el uso de tokens inválidos o caducados
 *
 * @param {*} req
 * @param {*} res
 * @param {*} next
 * @returns
 */
function ensureAuthenticated(req, res, next) {
  try {
    const { authorization: token } = req.headers;

    if (!token) {
      return res
        .status(403)
        .send({ message: "Tu petición no tiene cabecera de autorización" });
    }

    const payload = jwt.decode(token, config.TOKEN_SECRET);

    req.user = payload.sub;
    next();
  } catch (error) {
    if (error.message == "Token expired")
      return res.status(401).send({ message: "El token ha expirado" });
    return res.status(403).send({ message: "Token incorrecto" });
  }
}

/*
async function ensureAuthenticated(req, res, next) {
  try {
    const { authorization: token } = req.headers;

    if (!token) {
      return res
        .status(403)
        .send({ message: constants.TR_AUTHORIZATION_REQUIRED });
    }
    const payload = jwt.decode(token, config.secretKeyJWT);

    const bookingConfig = await getBookingConfig({
      idCompany: payload.idCompany,
    });
    req.bookingConfig = bookingConfig;
    next();
  } catch (error) {
    return res.status(403).send({ message: constants.TR_TOKEN_INCORRECT });
  }
}

function ensureAdmin(req, res, next) {
  try {
    const { authorization: token } = req.headers;

    if (!token) throw new Error("Authorization is required");
    if (token !== config.adminToken) throw new Error("Token incorrect");

    next();
  } catch (error) {
    return res.status(403).send({ message: error.message });
  }
}

async function ensureAdminLogin(req, res, next) {
  try {
    const { authorization: token } = req.headers;
    const { idCompany } = req.body;

    if (!token) {
      return res
        .status(403)
        .send({ message: constants.TR_AUTHORIZATION_REQUIRED });
    }

    //idCompany del que piden info
    if (!idCompany) {
      return res
        .status(400)
        .send({ message: "Bad Request: idCompany is required" });
    }

    //Extraemos el id de usuario del token
    const payload = decodeToken(token);
    if (!payload || !payload.id) {
      return res.status(403).send({ message: constants.TR_INVALID_TOKEN });
    }
    const { id } = payload;

    if (!id) {
      return res.status(403).send({ message: constants.TR_INVALID_TOKEN });
    }

    //Buscamos la fila del usuario con ese id
    const user = await Users.getUserData({ id });
    if (!user) {
      return res.status(403).send({ message: constants.TR_INVALID_TOKEN });
    }

    //Buscamos sus kartings en la tabla users_company
    const companies = await UsersCompany.findUserCompanyByUserId(id);
    if (!companies || companies.length === 0) {
      return res.status(404).send({ message: constants.TR_COMPANY_NOT_FOUND });
    }

    let included = false;
    for (const company of companies) {
      if (company.idCompany === idCompany) {
        included = true;
      }
    }

    //Si la idCompany que se pide no está entre las del usuario devolvemos token no válido
    if (!included) {
      return res.status(403).send({ message: constants.TR_INVALID_TOKEN });
    }

    //Buscamos la configuración de la idCompany que se pide
    const bookingConfig = await getBookingConfig({
      idCompany,
    });

    req.user = user;
    req.bookingConfig = bookingConfig;

    next();
  } catch (error) {
    return res.status(403).send({ message: error.message });
  }
}
*/

export { ensureAuthenticated };
