import { errors } from "celebrate";
import express from "express";
import { ensureAuthenticated } from "../middleware";
import exerciseRouter from "./exercise";
import incidenceRouter from "./incidence";
import loginRouter from "./login";
import monitorRouter from "./monitor";
import registerRouter from "./register";
import userRouter from "./user";
import workoutRouter from "./workout";

const router = express.Router();

router.get("/", (req, res) => {
  //process.env.npm_package_version
  res.json({ name: process.env.npm_package_name, version: process.env.npm_package_version, author: process.env.npm_package_author });
});

router.use("/login", loginRouter);
router.use("/register", registerRouter);
router.use("/incidence", incidenceRouter);
router.use("/user", userRouter);
router.use("/workout", workoutRouter);
router.use("/monitor", monitorRouter);
router.use("/exercise", exerciseRouter);

// Ruta solo accesible si estás autenticado (/private)
router.get("/private", ensureAuthenticated, (req, res) =>
  res.status(200).send({ msg: "Si lees esto, eres un privilegiado" })
);

//Por si atacan a una url que no tenemos definida, que no haga crash el programa
router.all("*", (req, res) => {
  res.status(404).send("Url not found.");
});

//Para mostrar los errores del celebrate cuando validamos los request params y body
router.use(errors());

export default router;
