import { celebrate, Joi } from "celebrate";
import express from "express";
import { Monitor } from "../controllers";

const router = express.Router();

router.get(
  "/:id/users",
  celebrate(
    {
      params: {
        id: Joi.string().required(),
      },
    },
    { abortEarly: false }
  ),

  (req, res) => {
      Monitor.getMonitorUsers(req, res);
  }
);

router.get(
  "/:id/workouts",
  celebrate(
    {
      params: {
        id: Joi.string().required(),
      },
    },
    { abortEarly: false }
  ),

  (req, res) => {
      Monitor.getMonitorWorkouts(req, res);
  }
);

router.get(
    "/:id",
    celebrate(
      {
        params: {
          id: Joi.string().required(),
        },
      },
      { abortEarly: false }
    ),
  
    (req, res) => {
        Monitor.getMonitor(req, res);
    }
  );

router.put(
  "/:id",
  celebrate(
    {
      body: Joi.object().keys({
        name: Joi.string().required(),
        surname: Joi.string().allow(null),
        birthday: Joi.date().optional().allow(null),
        gender: Joi.string().allow(null),
        email: Joi.string().required(),
        password: Joi.string().required(),
      }),
    },
    { abortEarly: false }
  ),
  (req, res) => {
    Monitor.updateMonitor(req, res);
  }
);


export default router;
