import { celebrate, Joi } from "celebrate";
import express from "express";
import { User } from "../controllers";

const router = express.Router();

router.get(
  "/:id/statistics",
  celebrate(
    {
      params: {
        id: Joi.string().required(),
      },
    },
    { abortEarly: false }
  ),

  (req, res) => {
      User.getUserStatistics(req, res);
  }
);

router.get(
    "/:id",
    celebrate(
      {
        params: {
          id: Joi.string().required(),
        },
      },
      { abortEarly: false }
    ),
  
    (req, res) => {
        User.getUser(req, res);
    }
  );

  
router.post(
  "/startWorkout",
  celebrate(
    {
      body: Joi.object().keys({
        userId: Joi.string().required(),
        workoutId: Joi.number().required(),
      }),
    },
    { abortEarly: false }
  ),
  (req, res) => {
    User.startUserWorkout(req, res);
  }
);

router.post(
  "/stopWorkout",
  celebrate(
    {
      body: Joi.object().keys({
        userId: Joi.string().required(),
        workoutId: Joi.number().required(),
      }),
    },
    { abortEarly: false }
  ),
  (req, res) => {
    User.stopUserWorkout(req, res);
  }
);

router.put(
  "/:id/updateWorkout",
  celebrate(
    {
      body: Joi.object().keys({
        workoutId: Joi.number().required()
      }),
    },
    { abortEarly: false }
  ),
  (req, res) => {
    User.updateUserWorkout(req, res);
  }
);

router.put(
  "/:id",
  celebrate(
    {
      body: Joi.object().keys({
        name: Joi.string().required(),
        surname: Joi.string().allow(null),
        birthday: Joi.date().optional().allow(null),
        gender: Joi.string().allow(null),
        email: Joi.string().required(),
        password: Joi.string().required(),
      }),
    },
    { abortEarly: false }
  ),
  (req, res) => {
    User.updateUser(req, res);
  }
);


export default router;
