import { celebrate, Joi } from "celebrate";
import express from "express";
import { config } from "../config";
import { Workout } from "../controllers";
import { constants } from "../utils";

const router = express.Router();


  router.get(
    "/user/:id",
    celebrate(
      {
        params: {
          id: Joi.string().required(),
        },
      },
      { abortEarly: false }
    ),
  
    (req, res) => {
        Workout.getUserWorkout(req, res);
    }
  );

router.get(
    "/:id",
    celebrate(
      {
        params: {
          id: Joi.string().required(),
        },
      },
      { abortEarly: false }
    ),
  
    (req, res) => {
        Workout.getWorkout(req, res);
    }
  );

router.post(
  "/",
  celebrate(
    {
      body: Joi.object().keys({
        workoutName: Joi.string().required(),
        monitorId: Joi.number().integer().required(),
      })
    },
    { abortEarly: false }
  ),
  (req, res) => {
    Workout.createWorkout(req, res);
  }
);

router.post(
  "/addExercise",
  celebrate(
    {
      body: Joi.object().keys({
        workoutId: Joi.number().integer().required(),
        exerciseId: Joi.number().integer().required()
      })
    },
    { abortEarly: false }
  ),
  (req, res) => {
    Workout.addExerciseToWorkout(req, res);
  }
);

router.put(
    "/",
    celebrate(
        {
        body: Joi.object().keys({
            id: Joi.number()
            .integer()
            .required(),
            name: Joi.string().required()
        }),
        headers: Joi.object({
            authorization: Joi.string()
            .required()
            .valid(config.TOKEN_SECRET)
            .error(new Error(constants.TR_AUTHORIZATION_REQUIRED))
        }).unknown()
        },
        { abortEarly: false }
    ),
    function(req, res) {
        Workout.updateWorkout(req, res);
    }
);
  
router.delete(
    "/",
    celebrate(
      {
        body: Joi.object().keys({
          workoutId: Joi.number()
            .integer()
            .required()
        }),
        // headers: Joi.object({
        //   authorization: Joi.string()
        //     .required()
        //     .valid(config.TOKEN_SECRET)
        //     .error(new Error(constants.TR_AUTHORIZATION_REQUIRED))
        // }).unknown()
      },
      { abortEarly: false }
    ),
    function(req, res) {
        Workout.deleteWorkout(req, res);
    }
);

router.delete(
  "/:workoutId/exercise/:exerciseId",
  celebrate(
    {
      params: {
        workoutId: Joi.string().required(),
        exerciseId: Joi.string().required(),
      },
    },
    { abortEarly: false }
  ),
  (req, res) => {
    Workout.deleteExerciseToWorkout(req, res);
  }
);

export default router;
