import moment from "moment";

const defaultFormatter = "YYYY-MM-DDTHH:mm:ss";

const vaucherDate = "2200-01-01T12:00:00Z";

const UTCToLocalConverter = (
  utcDateTime,
  timezone,
  formatter = defaultFormatter
) => moment(utcDateTime).tz(timezone).format(formatter);

const UTCToTimestampConverter = (utc) => {
  const localDate = utc.substring(0, utc.length - 1);
  return moment(localDate).format("HH:mm:ss");
};

const getWeekDay = (date) => {
  const days = ["SU", "MO", "TU", "WE", "TH", "FR", "SA"];

  return days[date.getDay()];
};

const isSameDates = (firstDate, secondDate) => {
  const date1 = moment(firstDate).format("L");
  const date2 = moment(secondDate).format("L");
  return date1 === date2;
};

const isDateVoucherMode = (date) =>
  isSameDates(date, vaucherDate) ? true : false;

const retrieveFakeDates = (datesBooking) =>
  datesBooking.map(
    (x) => `<br>${moment(x).tz("Africa/Bamako").format("DD-MM-YYYY HH:mm")}`
  );


const isToday = (someDate) => {
  const today = new Date();
  return (
    someDate.getDate() === today.getDate() &&
    someDate.getMonth() === today.getMonth() &&
    someDate.getFullYear() === today.getFullYear()
  );
};

const getTodayTimeZone = (
  timezone = "Europe/Madrid",
  formatter = defaultFormatter
) => moment().tz(timezone).format(formatter);

const getFakeTimeZone = (
  timezone = "Africa/Bamako",
  formatter = defaultFormatter
) => moment(vaucherDate).tz(timezone);

const isMinorDates = (firstDate, secondDate) =>
  moment(firstDate).format(defaultFormatter) <
  moment(secondDate).format(defaultFormatter);

const dateIsMinorToday = (date, timezone) => {
  const today = getTodayTimeZone(timezone);
  return isMinorDates(date, today);
};

const dateExceedMaxDaysBooking = (date, timezone, maxDays) => {
  if (!maxDays) return false;
  const bookingDate = moment(date).format("YYYY-MM-DD");
  const maxDate = moment()
    .tz(timezone)
    .add(maxDays, "days")
    .format("YYYY-MM-DD");
  return bookingDate > maxDate;
};

const getToday = (timezone = "Europe/Madrid") => {
  return moment().tz(timezone);
}

export {
  vaucherDate,
  UTCToLocalConverter,
  UTCToTimestampConverter,
  retrieveFakeDates,
  getWeekDay,
  isToday,
  isSameDates,
  getTodayTimeZone,
  getFakeTimeZone,
  isMinorDates,
  dateIsMinorToday,
  dateExceedMaxDaysBooking,
  isDateVoucherMode,
  getToday
};
